# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.bare_metal_solution import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.bare_metal_solution_v2.services.bare_metal_solution.async_client import (
    BareMetalSolutionAsyncClient,
)
from google.cloud.bare_metal_solution_v2.services.bare_metal_solution.client import (
    BareMetalSolutionClient,
)
from google.cloud.bare_metal_solution_v2.types.baremetalsolution import (
    OperationMetadata,
    ResetInstanceResponse,
)
from google.cloud.bare_metal_solution_v2.types.common import (
    VolumePerformanceTier,
    WorkloadProfile,
)
from google.cloud.bare_metal_solution_v2.types.instance import (
    DetachLunRequest,
    DisableInteractiveSerialConsoleRequest,
    DisableInteractiveSerialConsoleResponse,
    EnableInteractiveSerialConsoleRequest,
    EnableInteractiveSerialConsoleResponse,
    GetInstanceRequest,
    Instance,
    ListInstancesRequest,
    ListInstancesResponse,
    RenameInstanceRequest,
    ResetInstanceRequest,
    ServerNetworkTemplate,
    StartInstanceRequest,
    StartInstanceResponse,
    StopInstanceRequest,
    StopInstanceResponse,
    UpdateInstanceRequest,
)
from google.cloud.bare_metal_solution_v2.types.lun import (
    EvictLunRequest,
    GetLunRequest,
    ListLunsRequest,
    ListLunsResponse,
    Lun,
)
from google.cloud.bare_metal_solution_v2.types.network import (
    VRF,
    GetNetworkRequest,
    ListNetworksRequest,
    ListNetworksResponse,
    ListNetworkUsageRequest,
    ListNetworkUsageResponse,
    LogicalInterface,
    Network,
    NetworkAddressReservation,
    NetworkMountPoint,
    NetworkUsage,
    RenameNetworkRequest,
    UpdateNetworkRequest,
)
from google.cloud.bare_metal_solution_v2.types.nfs_share import (
    CreateNfsShareRequest,
    DeleteNfsShareRequest,
    GetNfsShareRequest,
    ListNfsSharesRequest,
    ListNfsSharesResponse,
    NfsShare,
    RenameNfsShareRequest,
    UpdateNfsShareRequest,
)
from google.cloud.bare_metal_solution_v2.types.osimage import (
    ListOSImagesRequest,
    ListOSImagesResponse,
    OSImage,
)
from google.cloud.bare_metal_solution_v2.types.provisioning import (
    CreateProvisioningConfigRequest,
    GetProvisioningConfigRequest,
    InstanceConfig,
    InstanceQuota,
    ListProvisioningQuotasRequest,
    ListProvisioningQuotasResponse,
    NetworkConfig,
    ProvisioningConfig,
    ProvisioningQuota,
    SubmitProvisioningConfigRequest,
    SubmitProvisioningConfigResponse,
    UpdateProvisioningConfigRequest,
    VolumeConfig,
)
from google.cloud.bare_metal_solution_v2.types.ssh_key import (
    CreateSSHKeyRequest,
    DeleteSSHKeyRequest,
    ListSSHKeysRequest,
    ListSSHKeysResponse,
    SSHKey,
)
from google.cloud.bare_metal_solution_v2.types.volume import (
    EvictVolumeRequest,
    GetVolumeRequest,
    ListVolumesRequest,
    ListVolumesResponse,
    RenameVolumeRequest,
    ResizeVolumeRequest,
    UpdateVolumeRequest,
    Volume,
)
from google.cloud.bare_metal_solution_v2.types.volume_snapshot import (
    CreateVolumeSnapshotRequest,
    DeleteVolumeSnapshotRequest,
    GetVolumeSnapshotRequest,
    ListVolumeSnapshotsRequest,
    ListVolumeSnapshotsResponse,
    RestoreVolumeSnapshotRequest,
    VolumeSnapshot,
)

__all__ = (
    "BareMetalSolutionClient",
    "BareMetalSolutionAsyncClient",
    "OperationMetadata",
    "ResetInstanceResponse",
    "VolumePerformanceTier",
    "WorkloadProfile",
    "DetachLunRequest",
    "DisableInteractiveSerialConsoleRequest",
    "DisableInteractiveSerialConsoleResponse",
    "EnableInteractiveSerialConsoleRequest",
    "EnableInteractiveSerialConsoleResponse",
    "GetInstanceRequest",
    "Instance",
    "ListInstancesRequest",
    "ListInstancesResponse",
    "RenameInstanceRequest",
    "ResetInstanceRequest",
    "ServerNetworkTemplate",
    "StartInstanceRequest",
    "StartInstanceResponse",
    "StopInstanceRequest",
    "StopInstanceResponse",
    "UpdateInstanceRequest",
    "EvictLunRequest",
    "GetLunRequest",
    "ListLunsRequest",
    "ListLunsResponse",
    "Lun",
    "GetNetworkRequest",
    "ListNetworksRequest",
    "ListNetworksResponse",
    "ListNetworkUsageRequest",
    "ListNetworkUsageResponse",
    "LogicalInterface",
    "Network",
    "NetworkAddressReservation",
    "NetworkMountPoint",
    "NetworkUsage",
    "RenameNetworkRequest",
    "UpdateNetworkRequest",
    "VRF",
    "CreateNfsShareRequest",
    "DeleteNfsShareRequest",
    "GetNfsShareRequest",
    "ListNfsSharesRequest",
    "ListNfsSharesResponse",
    "NfsShare",
    "RenameNfsShareRequest",
    "UpdateNfsShareRequest",
    "ListOSImagesRequest",
    "ListOSImagesResponse",
    "OSImage",
    "CreateProvisioningConfigRequest",
    "GetProvisioningConfigRequest",
    "InstanceConfig",
    "InstanceQuota",
    "ListProvisioningQuotasRequest",
    "ListProvisioningQuotasResponse",
    "NetworkConfig",
    "ProvisioningConfig",
    "ProvisioningQuota",
    "SubmitProvisioningConfigRequest",
    "SubmitProvisioningConfigResponse",
    "UpdateProvisioningConfigRequest",
    "VolumeConfig",
    "CreateSSHKeyRequest",
    "DeleteSSHKeyRequest",
    "ListSSHKeysRequest",
    "ListSSHKeysResponse",
    "SSHKey",
    "EvictVolumeRequest",
    "GetVolumeRequest",
    "ListVolumesRequest",
    "ListVolumesResponse",
    "RenameVolumeRequest",
    "ResizeVolumeRequest",
    "UpdateVolumeRequest",
    "Volume",
    "CreateVolumeSnapshotRequest",
    "DeleteVolumeSnapshotRequest",
    "GetVolumeSnapshotRequest",
    "ListVolumeSnapshotsRequest",
    "ListVolumeSnapshotsResponse",
    "RestoreVolumeSnapshotRequest",
    "VolumeSnapshot",
)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from typing import Awaitable, Callable, Dict, Optional, Sequence, Tuple, Union
import warnings

from google.api_core import gapic_v1, grpc_helpers_async, operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.auth.transport.grpc import SslCredentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.iam.v1 import iam_policy_pb2  # type: ignore
from google.iam.v1 import policy_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore
import grpc  # type: ignore
from grpc.experimental import aio  # type: ignore

from google.cloud.bare_metal_solution_v2.types import nfs_share as gcb_nfs_share
from google.cloud.bare_metal_solution_v2.types import (
    volume_snapshot as gcb_volume_snapshot,
)
from google.cloud.bare_metal_solution_v2.types import instance
from google.cloud.bare_metal_solution_v2.types import instance as gcb_instance
from google.cloud.bare_metal_solution_v2.types import lun
from google.cloud.bare_metal_solution_v2.types import network
from google.cloud.bare_metal_solution_v2.types import network as gcb_network
from google.cloud.bare_metal_solution_v2.types import nfs_share
from google.cloud.bare_metal_solution_v2.types import osimage, provisioning
from google.cloud.bare_metal_solution_v2.types import ssh_key
from google.cloud.bare_metal_solution_v2.types import ssh_key as gcb_ssh_key
from google.cloud.bare_metal_solution_v2.types import volume
from google.cloud.bare_metal_solution_v2.types import volume as gcb_volume
from google.cloud.bare_metal_solution_v2.types import volume_snapshot

from .base import DEFAULT_CLIENT_INFO, BareMetalSolutionTransport
from .grpc import BareMetalSolutionGrpcTransport


class BareMetalSolutionGrpcAsyncIOTransport(BareMetalSolutionTransport):
    """gRPC AsyncIO backend transport for BareMetalSolution.

    Performs management operations on Bare Metal Solution servers.

    The ``baremetalsolution.googleapis.com`` service provides management
    capabilities for Bare Metal Solution servers. To access the API
    methods, you must assign Bare Metal Solution IAM roles containing
    the desired permissions to your staff in your Google Cloud project.
    You must also enable the Bare Metal Solution API. Once enabled, the
    methods act upon specific servers in your Bare Metal Solution
    environment.

    This class defines the same methods as the primary client, so the
    primary client can load the underlying transport implementation
    and call it.

    It sends protocol buffers over the wire using gRPC (which is built on
    top of HTTP/2); the ``grpcio`` package must be installed.
    """

    _grpc_channel: aio.Channel
    _stubs: Dict[str, Callable] = {}

    @classmethod
    def create_channel(
        cls,
        host: str = "baremetalsolution.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        **kwargs,
    ) -> aio.Channel:
        """Create and return a gRPC AsyncIO channel object.
        Args:
            host (Optional[str]): The host for the channel to use.
            credentials (Optional[~.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If
                none are specified, the client will attempt to ascertain
                the credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            kwargs (Optional[dict]): Keyword arguments, which are passed to the
                channel creation.
        Returns:
            aio.Channel: A gRPC AsyncIO channel object.
        """

        return grpc_helpers_async.create_channel(
            host,
            credentials=credentials,
            credentials_file=credentials_file,
            quota_project_id=quota_project_id,
            default_scopes=cls.AUTH_SCOPES,
            scopes=scopes,
            default_host=cls.DEFAULT_HOST,
            **kwargs,
        )

    def __init__(
        self,
        *,
        host: str = "baremetalsolution.googleapis.com",
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        channel: Optional[aio.Channel] = None,
        api_mtls_endpoint: Optional[str] = None,
        client_cert_source: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        ssl_channel_credentials: Optional[grpc.ChannelCredentials] = None,
        client_cert_source_for_mtls: Optional[Callable[[], Tuple[bytes, bytes]]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is ignored if ``channel`` is provided.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is ignored if ``channel`` is provided.
            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                service. These are only used when credentials are not specified and
                are passed to :func:`google.auth.default`.
            channel (Optional[aio.Channel]): A ``Channel`` instance through
                which to make calls.
            api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                If provided, it overrides the ``host`` argument and tries to create
                a mutual TLS channel with client SSL credentials from
                ``client_cert_source`` or application default SSL credentials.
            client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                Deprecated. A callback to provide client SSL certificate bytes and
                private key bytes, both in PEM format. It is ignored if
                ``api_mtls_endpoint`` is None.
            ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
                for the grpc channel. It is ignored if ``channel`` is provided.
            client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                A callback to provide client certificate bytes and private key bytes,
                both in PEM format. It is used to configure a mutual TLS channel. It is
                ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.

        Raises:
            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
              creation failed for any reason.
          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
              and ``credentials_file`` are passed.
        """
        self._grpc_channel = None
        self._ssl_channel_credentials = ssl_channel_credentials
        self._stubs: Dict[str, Callable] = {}
        self._operations_client: Optional[operations_v1.OperationsAsyncClient] = None

        if api_mtls_endpoint:
            warnings.warn("api_mtls_endpoint is deprecated", DeprecationWarning)
        if client_cert_source:
            warnings.warn("client_cert_source is deprecated", DeprecationWarning)

        if channel:
            # Ignore credentials if a channel was passed.
            credentials = False
            # If a channel was explicitly provided, set it.
            self._grpc_channel = channel
            self._ssl_channel_credentials = None
        else:
            if api_mtls_endpoint:
                host = api_mtls_endpoint

                # Create SSL credentials with client_cert_source or application
                # default SSL credentials.
                if client_cert_source:
                    cert, key = client_cert_source()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )
                else:
                    self._ssl_channel_credentials = SslCredentials().ssl_credentials

            else:
                if client_cert_source_for_mtls and not ssl_channel_credentials:
                    cert, key = client_cert_source_for_mtls()
                    self._ssl_channel_credentials = grpc.ssl_channel_credentials(
                        certificate_chain=cert, private_key=key
                    )

        # The base transport sets the host, credentials and scopes
        super().__init__(
            host=host,
            credentials=credentials,
            credentials_file=credentials_file,
            scopes=scopes,
            quota_project_id=quota_project_id,
            client_info=client_info,
            always_use_jwt_access=always_use_jwt_access,
            api_audience=api_audience,
        )

        if not self._grpc_channel:
            self._grpc_channel = type(self).create_channel(
                self._host,
                # use the credentials which are saved
                credentials=self._credentials,
                # Set ``credentials_file`` to ``None`` here as
                # the credentials that we saved earlier should be used.
                credentials_file=None,
                scopes=self._scopes,
                ssl_credentials=self._ssl_channel_credentials,
                quota_project_id=quota_project_id,
                options=[
                    ("grpc.max_send_message_length", -1),
                    ("grpc.max_receive_message_length", -1),
                ],
            )

        # Wrap messages. This must be done after self._grpc_channel exists
        self._prep_wrapped_messages(client_info)

    @property
    def grpc_channel(self) -> aio.Channel:
        """Create the channel designed to connect to this service.

        This property caches on the instance; repeated calls return
        the same channel.
        """
        # Return the channel from cache.
        return self._grpc_channel

    @property
    def operations_client(self) -> operations_v1.OperationsAsyncClient:
        """Create the client designed to process long-running operations.

        This property caches on the instance; repeated calls return the same
        client.
        """
        # Quick check: Only create a new client if we do not already have one.
        if self._operations_client is None:
            self._operations_client = operations_v1.OperationsAsyncClient(
                self.grpc_channel
            )

        # Return the client from cache.
        return self._operations_client

    @property
    def list_instances(
        self,
    ) -> Callable[
        [instance.ListInstancesRequest], Awaitable[instance.ListInstancesResponse]
    ]:
        r"""Return a callable for the list instances method over gRPC.

        List servers in a given project and location.

        Returns:
            Callable[[~.ListInstancesRequest],
                    Awaitable[~.ListInstancesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_instances" not in self._stubs:
            self._stubs["list_instances"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListInstances",
                request_serializer=instance.ListInstancesRequest.serialize,
                response_deserializer=instance.ListInstancesResponse.deserialize,
            )
        return self._stubs["list_instances"]

    @property
    def get_instance(
        self,
    ) -> Callable[[instance.GetInstanceRequest], Awaitable[instance.Instance]]:
        r"""Return a callable for the get instance method over gRPC.

        Get details about a single server.

        Returns:
            Callable[[~.GetInstanceRequest],
                    Awaitable[~.Instance]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_instance" not in self._stubs:
            self._stubs["get_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetInstance",
                request_serializer=instance.GetInstanceRequest.serialize,
                response_deserializer=instance.Instance.deserialize,
            )
        return self._stubs["get_instance"]

    @property
    def update_instance(
        self,
    ) -> Callable[
        [gcb_instance.UpdateInstanceRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the update instance method over gRPC.

        Update details of a single server.

        Returns:
            Callable[[~.UpdateInstanceRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_instance" not in self._stubs:
            self._stubs["update_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/UpdateInstance",
                request_serializer=gcb_instance.UpdateInstanceRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_instance"]

    @property
    def rename_instance(
        self,
    ) -> Callable[[instance.RenameInstanceRequest], Awaitable[instance.Instance]]:
        r"""Return a callable for the rename instance method over gRPC.

        RenameInstance sets a new name for an instance.
        Use with caution, previous names become immediately
        invalidated.

        Returns:
            Callable[[~.RenameInstanceRequest],
                    Awaitable[~.Instance]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "rename_instance" not in self._stubs:
            self._stubs["rename_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/RenameInstance",
                request_serializer=instance.RenameInstanceRequest.serialize,
                response_deserializer=instance.Instance.deserialize,
            )
        return self._stubs["rename_instance"]

    @property
    def reset_instance(
        self,
    ) -> Callable[[instance.ResetInstanceRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the reset instance method over gRPC.

        Perform an ungraceful, hard reset on a server.
        Equivalent to shutting the power off and then turning it
        back on.

        Returns:
            Callable[[~.ResetInstanceRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "reset_instance" not in self._stubs:
            self._stubs["reset_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ResetInstance",
                request_serializer=instance.ResetInstanceRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["reset_instance"]

    @property
    def start_instance(
        self,
    ) -> Callable[[instance.StartInstanceRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the start instance method over gRPC.

        Starts a server that was shutdown.

        Returns:
            Callable[[~.StartInstanceRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "start_instance" not in self._stubs:
            self._stubs["start_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/StartInstance",
                request_serializer=instance.StartInstanceRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["start_instance"]

    @property
    def stop_instance(
        self,
    ) -> Callable[[instance.StopInstanceRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the stop instance method over gRPC.

        Stop a running server.

        Returns:
            Callable[[~.StopInstanceRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "stop_instance" not in self._stubs:
            self._stubs["stop_instance"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/StopInstance",
                request_serializer=instance.StopInstanceRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["stop_instance"]

    @property
    def enable_interactive_serial_console(
        self,
    ) -> Callable[
        [instance.EnableInteractiveSerialConsoleRequest],
        Awaitable[operations_pb2.Operation],
    ]:
        r"""Return a callable for the enable interactive serial
        console method over gRPC.

        Enable the interactive serial console feature on an
        instance.

        Returns:
            Callable[[~.EnableInteractiveSerialConsoleRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "enable_interactive_serial_console" not in self._stubs:
            self._stubs[
                "enable_interactive_serial_console"
            ] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/EnableInteractiveSerialConsole",
                request_serializer=instance.EnableInteractiveSerialConsoleRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["enable_interactive_serial_console"]

    @property
    def disable_interactive_serial_console(
        self,
    ) -> Callable[
        [instance.DisableInteractiveSerialConsoleRequest],
        Awaitable[operations_pb2.Operation],
    ]:
        r"""Return a callable for the disable interactive serial
        console method over gRPC.

        Disable the interactive serial console feature on an
        instance.

        Returns:
            Callable[[~.DisableInteractiveSerialConsoleRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "disable_interactive_serial_console" not in self._stubs:
            self._stubs[
                "disable_interactive_serial_console"
            ] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/DisableInteractiveSerialConsole",
                request_serializer=instance.DisableInteractiveSerialConsoleRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["disable_interactive_serial_console"]

    @property
    def detach_lun(
        self,
    ) -> Callable[[gcb_instance.DetachLunRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the detach lun method over gRPC.

        Detach LUN from Instance.

        Returns:
            Callable[[~.DetachLunRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "detach_lun" not in self._stubs:
            self._stubs["detach_lun"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/DetachLun",
                request_serializer=gcb_instance.DetachLunRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["detach_lun"]

    @property
    def list_ssh_keys(
        self,
    ) -> Callable[[ssh_key.ListSSHKeysRequest], Awaitable[ssh_key.ListSSHKeysResponse]]:
        r"""Return a callable for the list ssh keys method over gRPC.

        Lists the public SSH keys registered for the
        specified project. These SSH keys are used only for the
        interactive serial console feature.

        Returns:
            Callable[[~.ListSSHKeysRequest],
                    Awaitable[~.ListSSHKeysResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_ssh_keys" not in self._stubs:
            self._stubs["list_ssh_keys"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListSSHKeys",
                request_serializer=ssh_key.ListSSHKeysRequest.serialize,
                response_deserializer=ssh_key.ListSSHKeysResponse.deserialize,
            )
        return self._stubs["list_ssh_keys"]

    @property
    def create_ssh_key(
        self,
    ) -> Callable[[gcb_ssh_key.CreateSSHKeyRequest], Awaitable[gcb_ssh_key.SSHKey]]:
        r"""Return a callable for the create ssh key method over gRPC.

        Register a public SSH key in the specified project
        for use with the interactive serial console feature.

        Returns:
            Callable[[~.CreateSSHKeyRequest],
                    Awaitable[~.SSHKey]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_ssh_key" not in self._stubs:
            self._stubs["create_ssh_key"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/CreateSSHKey",
                request_serializer=gcb_ssh_key.CreateSSHKeyRequest.serialize,
                response_deserializer=gcb_ssh_key.SSHKey.deserialize,
            )
        return self._stubs["create_ssh_key"]

    @property
    def delete_ssh_key(
        self,
    ) -> Callable[[ssh_key.DeleteSSHKeyRequest], Awaitable[empty_pb2.Empty]]:
        r"""Return a callable for the delete ssh key method over gRPC.

        Deletes a public SSH key registered in the specified
        project.

        Returns:
            Callable[[~.DeleteSSHKeyRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_ssh_key" not in self._stubs:
            self._stubs["delete_ssh_key"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/DeleteSSHKey",
                request_serializer=ssh_key.DeleteSSHKeyRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_ssh_key"]

    @property
    def list_volumes(
        self,
    ) -> Callable[[volume.ListVolumesRequest], Awaitable[volume.ListVolumesResponse]]:
        r"""Return a callable for the list volumes method over gRPC.

        List storage volumes in a given project and location.

        Returns:
            Callable[[~.ListVolumesRequest],
                    Awaitable[~.ListVolumesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_volumes" not in self._stubs:
            self._stubs["list_volumes"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListVolumes",
                request_serializer=volume.ListVolumesRequest.serialize,
                response_deserializer=volume.ListVolumesResponse.deserialize,
            )
        return self._stubs["list_volumes"]

    @property
    def get_volume(
        self,
    ) -> Callable[[volume.GetVolumeRequest], Awaitable[volume.Volume]]:
        r"""Return a callable for the get volume method over gRPC.

        Get details of a single storage volume.

        Returns:
            Callable[[~.GetVolumeRequest],
                    Awaitable[~.Volume]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_volume" not in self._stubs:
            self._stubs["get_volume"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetVolume",
                request_serializer=volume.GetVolumeRequest.serialize,
                response_deserializer=volume.Volume.deserialize,
            )
        return self._stubs["get_volume"]

    @property
    def update_volume(
        self,
    ) -> Callable[
        [gcb_volume.UpdateVolumeRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the update volume method over gRPC.

        Update details of a single storage volume.

        Returns:
            Callable[[~.UpdateVolumeRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_volume" not in self._stubs:
            self._stubs["update_volume"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/UpdateVolume",
                request_serializer=gcb_volume.UpdateVolumeRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_volume"]

    @property
    def rename_volume(
        self,
    ) -> Callable[[volume.RenameVolumeRequest], Awaitable[volume.Volume]]:
        r"""Return a callable for the rename volume method over gRPC.

        RenameVolume sets a new name for a volume.
        Use with caution, previous names become immediately
        invalidated.

        Returns:
            Callable[[~.RenameVolumeRequest],
                    Awaitable[~.Volume]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "rename_volume" not in self._stubs:
            self._stubs["rename_volume"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/RenameVolume",
                request_serializer=volume.RenameVolumeRequest.serialize,
                response_deserializer=volume.Volume.deserialize,
            )
        return self._stubs["rename_volume"]

    @property
    def evict_volume(
        self,
    ) -> Callable[[volume.EvictVolumeRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the evict volume method over gRPC.

        Skips volume's cooloff and deletes it now.
        Volume must be in cooloff state.

        Returns:
            Callable[[~.EvictVolumeRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "evict_volume" not in self._stubs:
            self._stubs["evict_volume"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/EvictVolume",
                request_serializer=volume.EvictVolumeRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["evict_volume"]

    @property
    def resize_volume(
        self,
    ) -> Callable[
        [gcb_volume.ResizeVolumeRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the resize volume method over gRPC.

        Emergency Volume resize.

        Returns:
            Callable[[~.ResizeVolumeRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "resize_volume" not in self._stubs:
            self._stubs["resize_volume"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ResizeVolume",
                request_serializer=gcb_volume.ResizeVolumeRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["resize_volume"]

    @property
    def list_networks(
        self,
    ) -> Callable[
        [network.ListNetworksRequest], Awaitable[network.ListNetworksResponse]
    ]:
        r"""Return a callable for the list networks method over gRPC.

        List network in a given project and location.

        Returns:
            Callable[[~.ListNetworksRequest],
                    Awaitable[~.ListNetworksResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_networks" not in self._stubs:
            self._stubs["list_networks"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListNetworks",
                request_serializer=network.ListNetworksRequest.serialize,
                response_deserializer=network.ListNetworksResponse.deserialize,
            )
        return self._stubs["list_networks"]

    @property
    def list_network_usage(
        self,
    ) -> Callable[
        [network.ListNetworkUsageRequest], Awaitable[network.ListNetworkUsageResponse]
    ]:
        r"""Return a callable for the list network usage method over gRPC.

        List all Networks (and used IPs for each Network) in
        the vendor account associated with the specified
        project.

        Returns:
            Callable[[~.ListNetworkUsageRequest],
                    Awaitable[~.ListNetworkUsageResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_network_usage" not in self._stubs:
            self._stubs["list_network_usage"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListNetworkUsage",
                request_serializer=network.ListNetworkUsageRequest.serialize,
                response_deserializer=network.ListNetworkUsageResponse.deserialize,
            )
        return self._stubs["list_network_usage"]

    @property
    def get_network(
        self,
    ) -> Callable[[network.GetNetworkRequest], Awaitable[network.Network]]:
        r"""Return a callable for the get network method over gRPC.

        Get details of a single network.

        Returns:
            Callable[[~.GetNetworkRequest],
                    Awaitable[~.Network]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_network" not in self._stubs:
            self._stubs["get_network"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetNetwork",
                request_serializer=network.GetNetworkRequest.serialize,
                response_deserializer=network.Network.deserialize,
            )
        return self._stubs["get_network"]

    @property
    def update_network(
        self,
    ) -> Callable[
        [gcb_network.UpdateNetworkRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the update network method over gRPC.

        Update details of a single network.

        Returns:
            Callable[[~.UpdateNetworkRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_network" not in self._stubs:
            self._stubs["update_network"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/UpdateNetwork",
                request_serializer=gcb_network.UpdateNetworkRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_network"]

    @property
    def create_volume_snapshot(
        self,
    ) -> Callable[
        [gcb_volume_snapshot.CreateVolumeSnapshotRequest],
        Awaitable[gcb_volume_snapshot.VolumeSnapshot],
    ]:
        r"""Return a callable for the create volume snapshot method over gRPC.

        Takes a snapshot of a boot volume. Returns INVALID_ARGUMENT if
        called for a non-boot volume.

        Returns:
            Callable[[~.CreateVolumeSnapshotRequest],
                    Awaitable[~.VolumeSnapshot]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_volume_snapshot" not in self._stubs:
            self._stubs["create_volume_snapshot"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/CreateVolumeSnapshot",
                request_serializer=gcb_volume_snapshot.CreateVolumeSnapshotRequest.serialize,
                response_deserializer=gcb_volume_snapshot.VolumeSnapshot.deserialize,
            )
        return self._stubs["create_volume_snapshot"]

    @property
    def restore_volume_snapshot(
        self,
    ) -> Callable[
        [gcb_volume_snapshot.RestoreVolumeSnapshotRequest],
        Awaitable[operations_pb2.Operation],
    ]:
        r"""Return a callable for the restore volume snapshot method over gRPC.

        Uses the specified snapshot to restore its parent volume.
        Returns INVALID_ARGUMENT if called for a non-boot volume.

        Returns:
            Callable[[~.RestoreVolumeSnapshotRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "restore_volume_snapshot" not in self._stubs:
            self._stubs["restore_volume_snapshot"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/RestoreVolumeSnapshot",
                request_serializer=gcb_volume_snapshot.RestoreVolumeSnapshotRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["restore_volume_snapshot"]

    @property
    def delete_volume_snapshot(
        self,
    ) -> Callable[
        [volume_snapshot.DeleteVolumeSnapshotRequest], Awaitable[empty_pb2.Empty]
    ]:
        r"""Return a callable for the delete volume snapshot method over gRPC.

        Deletes a volume snapshot. Returns INVALID_ARGUMENT if called
        for a non-boot volume.

        Returns:
            Callable[[~.DeleteVolumeSnapshotRequest],
                    Awaitable[~.Empty]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_volume_snapshot" not in self._stubs:
            self._stubs["delete_volume_snapshot"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/DeleteVolumeSnapshot",
                request_serializer=volume_snapshot.DeleteVolumeSnapshotRequest.serialize,
                response_deserializer=empty_pb2.Empty.FromString,
            )
        return self._stubs["delete_volume_snapshot"]

    @property
    def get_volume_snapshot(
        self,
    ) -> Callable[
        [volume_snapshot.GetVolumeSnapshotRequest],
        Awaitable[volume_snapshot.VolumeSnapshot],
    ]:
        r"""Return a callable for the get volume snapshot method over gRPC.

        Returns the specified snapshot resource. Returns
        INVALID_ARGUMENT if called for a non-boot volume.

        Returns:
            Callable[[~.GetVolumeSnapshotRequest],
                    Awaitable[~.VolumeSnapshot]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_volume_snapshot" not in self._stubs:
            self._stubs["get_volume_snapshot"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetVolumeSnapshot",
                request_serializer=volume_snapshot.GetVolumeSnapshotRequest.serialize,
                response_deserializer=volume_snapshot.VolumeSnapshot.deserialize,
            )
        return self._stubs["get_volume_snapshot"]

    @property
    def list_volume_snapshots(
        self,
    ) -> Callable[
        [volume_snapshot.ListVolumeSnapshotsRequest],
        Awaitable[volume_snapshot.ListVolumeSnapshotsResponse],
    ]:
        r"""Return a callable for the list volume snapshots method over gRPC.

        Retrieves the list of snapshots for the specified
        volume. Returns a response with an empty list of
        snapshots if called for a non-boot volume.

        Returns:
            Callable[[~.ListVolumeSnapshotsRequest],
                    Awaitable[~.ListVolumeSnapshotsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_volume_snapshots" not in self._stubs:
            self._stubs["list_volume_snapshots"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListVolumeSnapshots",
                request_serializer=volume_snapshot.ListVolumeSnapshotsRequest.serialize,
                response_deserializer=volume_snapshot.ListVolumeSnapshotsResponse.deserialize,
            )
        return self._stubs["list_volume_snapshots"]

    @property
    def get_lun(self) -> Callable[[lun.GetLunRequest], Awaitable[lun.Lun]]:
        r"""Return a callable for the get lun method over gRPC.

        Get details of a single storage logical unit
        number(LUN).

        Returns:
            Callable[[~.GetLunRequest],
                    Awaitable[~.Lun]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_lun" not in self._stubs:
            self._stubs["get_lun"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetLun",
                request_serializer=lun.GetLunRequest.serialize,
                response_deserializer=lun.Lun.deserialize,
            )
        return self._stubs["get_lun"]

    @property
    def list_luns(
        self,
    ) -> Callable[[lun.ListLunsRequest], Awaitable[lun.ListLunsResponse]]:
        r"""Return a callable for the list luns method over gRPC.

        List storage volume luns for given storage volume.

        Returns:
            Callable[[~.ListLunsRequest],
                    Awaitable[~.ListLunsResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_luns" not in self._stubs:
            self._stubs["list_luns"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListLuns",
                request_serializer=lun.ListLunsRequest.serialize,
                response_deserializer=lun.ListLunsResponse.deserialize,
            )
        return self._stubs["list_luns"]

    @property
    def evict_lun(
        self,
    ) -> Callable[[lun.EvictLunRequest], Awaitable[operations_pb2.Operation]]:
        r"""Return a callable for the evict lun method over gRPC.

        Skips lun's cooloff and deletes it now.
        Lun must be in cooloff state.

        Returns:
            Callable[[~.EvictLunRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "evict_lun" not in self._stubs:
            self._stubs["evict_lun"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/EvictLun",
                request_serializer=lun.EvictLunRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["evict_lun"]

    @property
    def get_nfs_share(
        self,
    ) -> Callable[[nfs_share.GetNfsShareRequest], Awaitable[nfs_share.NfsShare]]:
        r"""Return a callable for the get nfs share method over gRPC.

        Get details of a single NFS share.

        Returns:
            Callable[[~.GetNfsShareRequest],
                    Awaitable[~.NfsShare]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_nfs_share" not in self._stubs:
            self._stubs["get_nfs_share"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetNfsShare",
                request_serializer=nfs_share.GetNfsShareRequest.serialize,
                response_deserializer=nfs_share.NfsShare.deserialize,
            )
        return self._stubs["get_nfs_share"]

    @property
    def list_nfs_shares(
        self,
    ) -> Callable[
        [nfs_share.ListNfsSharesRequest], Awaitable[nfs_share.ListNfsSharesResponse]
    ]:
        r"""Return a callable for the list nfs shares method over gRPC.

        List NFS shares.

        Returns:
            Callable[[~.ListNfsSharesRequest],
                    Awaitable[~.ListNfsSharesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_nfs_shares" not in self._stubs:
            self._stubs["list_nfs_shares"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListNfsShares",
                request_serializer=nfs_share.ListNfsSharesRequest.serialize,
                response_deserializer=nfs_share.ListNfsSharesResponse.deserialize,
            )
        return self._stubs["list_nfs_shares"]

    @property
    def update_nfs_share(
        self,
    ) -> Callable[
        [gcb_nfs_share.UpdateNfsShareRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the update nfs share method over gRPC.

        Update details of a single NFS share.

        Returns:
            Callable[[~.UpdateNfsShareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_nfs_share" not in self._stubs:
            self._stubs["update_nfs_share"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/UpdateNfsShare",
                request_serializer=gcb_nfs_share.UpdateNfsShareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["update_nfs_share"]

    @property
    def create_nfs_share(
        self,
    ) -> Callable[
        [gcb_nfs_share.CreateNfsShareRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the create nfs share method over gRPC.

        Create an NFS share.

        Returns:
            Callable[[~.CreateNfsShareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_nfs_share" not in self._stubs:
            self._stubs["create_nfs_share"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/CreateNfsShare",
                request_serializer=gcb_nfs_share.CreateNfsShareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["create_nfs_share"]

    @property
    def rename_nfs_share(
        self,
    ) -> Callable[[nfs_share.RenameNfsShareRequest], Awaitable[nfs_share.NfsShare]]:
        r"""Return a callable for the rename nfs share method over gRPC.

        RenameNfsShare sets a new name for an nfsshare.
        Use with caution, previous names become immediately
        invalidated.

        Returns:
            Callable[[~.RenameNfsShareRequest],
                    Awaitable[~.NfsShare]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "rename_nfs_share" not in self._stubs:
            self._stubs["rename_nfs_share"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/RenameNfsShare",
                request_serializer=nfs_share.RenameNfsShareRequest.serialize,
                response_deserializer=nfs_share.NfsShare.deserialize,
            )
        return self._stubs["rename_nfs_share"]

    @property
    def delete_nfs_share(
        self,
    ) -> Callable[
        [nfs_share.DeleteNfsShareRequest], Awaitable[operations_pb2.Operation]
    ]:
        r"""Return a callable for the delete nfs share method over gRPC.

        Delete an NFS share. The underlying volume is
        automatically deleted.

        Returns:
            Callable[[~.DeleteNfsShareRequest],
                    Awaitable[~.Operation]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "delete_nfs_share" not in self._stubs:
            self._stubs["delete_nfs_share"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/DeleteNfsShare",
                request_serializer=nfs_share.DeleteNfsShareRequest.serialize,
                response_deserializer=operations_pb2.Operation.FromString,
            )
        return self._stubs["delete_nfs_share"]

    @property
    def list_provisioning_quotas(
        self,
    ) -> Callable[
        [provisioning.ListProvisioningQuotasRequest],
        Awaitable[provisioning.ListProvisioningQuotasResponse],
    ]:
        r"""Return a callable for the list provisioning quotas method over gRPC.

        List the budget details to provision resources on a
        given project.

        Returns:
            Callable[[~.ListProvisioningQuotasRequest],
                    Awaitable[~.ListProvisioningQuotasResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_provisioning_quotas" not in self._stubs:
            self._stubs["list_provisioning_quotas"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListProvisioningQuotas",
                request_serializer=provisioning.ListProvisioningQuotasRequest.serialize,
                response_deserializer=provisioning.ListProvisioningQuotasResponse.deserialize,
            )
        return self._stubs["list_provisioning_quotas"]

    @property
    def submit_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.SubmitProvisioningConfigRequest],
        Awaitable[provisioning.SubmitProvisioningConfigResponse],
    ]:
        r"""Return a callable for the submit provisioning config method over gRPC.

        Submit a provisiong configuration for a given
        project.

        Returns:
            Callable[[~.SubmitProvisioningConfigRequest],
                    Awaitable[~.SubmitProvisioningConfigResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "submit_provisioning_config" not in self._stubs:
            self._stubs["submit_provisioning_config"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/SubmitProvisioningConfig",
                request_serializer=provisioning.SubmitProvisioningConfigRequest.serialize,
                response_deserializer=provisioning.SubmitProvisioningConfigResponse.deserialize,
            )
        return self._stubs["submit_provisioning_config"]

    @property
    def get_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.GetProvisioningConfigRequest],
        Awaitable[provisioning.ProvisioningConfig],
    ]:
        r"""Return a callable for the get provisioning config method over gRPC.

        Get ProvisioningConfig by name.

        Returns:
            Callable[[~.GetProvisioningConfigRequest],
                    Awaitable[~.ProvisioningConfig]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_provisioning_config" not in self._stubs:
            self._stubs["get_provisioning_config"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/GetProvisioningConfig",
                request_serializer=provisioning.GetProvisioningConfigRequest.serialize,
                response_deserializer=provisioning.ProvisioningConfig.deserialize,
            )
        return self._stubs["get_provisioning_config"]

    @property
    def create_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.CreateProvisioningConfigRequest],
        Awaitable[provisioning.ProvisioningConfig],
    ]:
        r"""Return a callable for the create provisioning config method over gRPC.

        Create new ProvisioningConfig.

        Returns:
            Callable[[~.CreateProvisioningConfigRequest],
                    Awaitable[~.ProvisioningConfig]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "create_provisioning_config" not in self._stubs:
            self._stubs["create_provisioning_config"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/CreateProvisioningConfig",
                request_serializer=provisioning.CreateProvisioningConfigRequest.serialize,
                response_deserializer=provisioning.ProvisioningConfig.deserialize,
            )
        return self._stubs["create_provisioning_config"]

    @property
    def update_provisioning_config(
        self,
    ) -> Callable[
        [provisioning.UpdateProvisioningConfigRequest],
        Awaitable[provisioning.ProvisioningConfig],
    ]:
        r"""Return a callable for the update provisioning config method over gRPC.

        Update existing ProvisioningConfig.

        Returns:
            Callable[[~.UpdateProvisioningConfigRequest],
                    Awaitable[~.ProvisioningConfig]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "update_provisioning_config" not in self._stubs:
            self._stubs["update_provisioning_config"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/UpdateProvisioningConfig",
                request_serializer=provisioning.UpdateProvisioningConfigRequest.serialize,
                response_deserializer=provisioning.ProvisioningConfig.deserialize,
            )
        return self._stubs["update_provisioning_config"]

    @property
    def rename_network(
        self,
    ) -> Callable[[network.RenameNetworkRequest], Awaitable[network.Network]]:
        r"""Return a callable for the rename network method over gRPC.

        RenameNetwork sets a new name for a network.
        Use with caution, previous names become immediately
        invalidated.

        Returns:
            Callable[[~.RenameNetworkRequest],
                    Awaitable[~.Network]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "rename_network" not in self._stubs:
            self._stubs["rename_network"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/RenameNetwork",
                request_serializer=network.RenameNetworkRequest.serialize,
                response_deserializer=network.Network.deserialize,
            )
        return self._stubs["rename_network"]

    @property
    def list_os_images(
        self,
    ) -> Callable[
        [osimage.ListOSImagesRequest], Awaitable[osimage.ListOSImagesResponse]
    ]:
        r"""Return a callable for the list os images method over gRPC.

        Retrieves the list of OS images which are currently
        approved.

        Returns:
            Callable[[~.ListOSImagesRequest],
                    Awaitable[~.ListOSImagesResponse]]:
                A function that, when called, will call the underlying RPC
                on the server.
        """
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_os_images" not in self._stubs:
            self._stubs["list_os_images"] = self.grpc_channel.unary_unary(
                "/google.cloud.baremetalsolution.v2.BareMetalSolution/ListOSImages",
                request_serializer=osimage.ListOSImagesRequest.serialize,
                response_deserializer=osimage.ListOSImagesResponse.deserialize,
            )
        return self._stubs["list_os_images"]

    def close(self):
        return self.grpc_channel.close()

    @property
    def list_locations(
        self,
    ) -> Callable[
        [locations_pb2.ListLocationsRequest], locations_pb2.ListLocationsResponse
    ]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "list_locations" not in self._stubs:
            self._stubs["list_locations"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/ListLocations",
                request_serializer=locations_pb2.ListLocationsRequest.SerializeToString,
                response_deserializer=locations_pb2.ListLocationsResponse.FromString,
            )
        return self._stubs["list_locations"]

    @property
    def get_location(
        self,
    ) -> Callable[[locations_pb2.GetLocationRequest], locations_pb2.Location]:
        r"""Return a callable for the list locations method over gRPC."""
        # Generate a "stub function" on-the-fly which will actually make
        # the request.
        # gRPC handles serialization and deserialization, so we just need
        # to pass in the functions for each.
        if "get_location" not in self._stubs:
            self._stubs["get_location"] = self.grpc_channel.unary_unary(
                "/google.cloud.location.Locations/GetLocation",
                request_serializer=locations_pb2.GetLocationRequest.SerializeToString,
                response_deserializer=locations_pb2.Location.FromString,
            )
        return self._stubs["get_location"]


__all__ = ("BareMetalSolutionGrpcAsyncIOTransport",)



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "Network",
        "NetworkAddressReservation",
        "VRF",
        "LogicalInterface",
        "GetNetworkRequest",
        "ListNetworksRequest",
        "ListNetworksResponse",
        "UpdateNetworkRequest",
        "NetworkUsage",
        "ListNetworkUsageRequest",
        "ListNetworkUsageResponse",
        "NetworkMountPoint",
        "RenameNetworkRequest",
    },
)


class Network(proto.Message):
    r"""A Network.

    Attributes:
        name (str):
            Output only. The resource name of this ``Network``. Resource
            names are schemeless URIs that follow the conventions in
            https://cloud.google.com/apis/design/resource_names. Format:
            ``projects/{project}/locations/{location}/networks/{network}``
        id (str):
            An identifier for the ``Network``, generated by the backend.
        type_ (google.cloud.bare_metal_solution_v2.types.Network.Type):
            The type of this network.
        ip_address (str):
            IP address configured.
        mac_address (MutableSequence[str]):
            List of physical interfaces.
        state (google.cloud.bare_metal_solution_v2.types.Network.State):
            The Network state.
        vlan_id (str):
            The vlan id of the Network.
        cidr (str):
            The cidr of the Network.
        vrf (google.cloud.bare_metal_solution_v2.types.VRF):
            The vrf for the Network.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        services_cidr (str):
            IP range for reserved for services (e.g.
            NFS).
        reservations (MutableSequence[google.cloud.bare_metal_solution_v2.types.NetworkAddressReservation]):
            List of IP address reservations in this
            network. When updating this field, an error will
            be generated if a reservation conflicts with an
            IP address already allocated to a physical
            server.
        pod (str):
            Output only. Pod name.
        mount_points (MutableSequence[google.cloud.bare_metal_solution_v2.types.NetworkMountPoint]):
            Input only. List of mount points to attach
            the network to.
        jumbo_frames_enabled (bool):
            Whether network uses standard frames or jumbo
            ones.
        gateway_ip (str):
            Output only. Gateway ip address.
    """

    class Type(proto.Enum):
        r"""Network type.

        Values:
            TYPE_UNSPECIFIED (0):
                Unspecified value.
            CLIENT (1):
                Client network, a network peered to a Google
                Cloud VPC.
            PRIVATE (2):
                Private network, a network local to the Bare
                Metal Solution environment.
        """
        TYPE_UNSPECIFIED = 0
        CLIENT = 1
        PRIVATE = 2

    class State(proto.Enum):
        r"""The possible states for this Network.

        Values:
            STATE_UNSPECIFIED (0):
                The Network is in an unknown state.
            PROVISIONING (1):
                The Network is provisioning.
            PROVISIONED (2):
                The Network has been provisioned.
            DEPROVISIONING (3):
                The Network is being deprovisioned.
            UPDATING (4):
                The Network is being updated.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        PROVISIONED = 2
        DEPROVISIONING = 3
        UPDATING = 4

    name: str = proto.Field(
        proto.STRING,
        number=5,
    )
    id: str = proto.Field(
        proto.STRING,
        number=10,
    )
    type_: Type = proto.Field(
        proto.ENUM,
        number=2,
        enum=Type,
    )
    ip_address: str = proto.Field(
        proto.STRING,
        number=3,
    )
    mac_address: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=6,
        enum=State,
    )
    vlan_id: str = proto.Field(
        proto.STRING,
        number=7,
    )
    cidr: str = proto.Field(
        proto.STRING,
        number=8,
    )
    vrf: "VRF" = proto.Field(
        proto.MESSAGE,
        number=9,
        message="VRF",
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=11,
    )
    services_cidr: str = proto.Field(
        proto.STRING,
        number=12,
    )
    reservations: MutableSequence["NetworkAddressReservation"] = proto.RepeatedField(
        proto.MESSAGE,
        number=13,
        message="NetworkAddressReservation",
    )
    pod: str = proto.Field(
        proto.STRING,
        number=14,
    )
    mount_points: MutableSequence["NetworkMountPoint"] = proto.RepeatedField(
        proto.MESSAGE,
        number=15,
        message="NetworkMountPoint",
    )
    jumbo_frames_enabled: bool = proto.Field(
        proto.BOOL,
        number=16,
    )
    gateway_ip: str = proto.Field(
        proto.STRING,
        number=17,
    )


class NetworkAddressReservation(proto.Message):
    r"""A reservation of one or more addresses in a network.

    Attributes:
        start_address (str):
            The first address of this reservation block.
            Must be specified as a single IPv4 address, e.g.
            10.1.2.2.
        end_address (str):
            The last address of this reservation block, inclusive. I.e.,
            for cases when reservations are only single addresses,
            end_address and start_address will be the same. Must be
            specified as a single IPv4 address, e.g. 10.1.2.2.
        note (str):
            A note about this reservation, intended for
            human consumption.
    """

    start_address: str = proto.Field(
        proto.STRING,
        number=1,
    )
    end_address: str = proto.Field(
        proto.STRING,
        number=2,
    )
    note: str = proto.Field(
        proto.STRING,
        number=3,
    )


class VRF(proto.Message):
    r"""A network VRF.

    Attributes:
        name (str):
            The name of the VRF.
        state (google.cloud.bare_metal_solution_v2.types.VRF.State):
            The possible state of VRF.
        qos_policy (google.cloud.bare_metal_solution_v2.types.VRF.QosPolicy):
            The QOS policy applied to this VRF.
            The value is only meaningful when all the vlan
            attachments have the same QoS. This field should
            not be used for new integrations, use vlan
            attachment level qos instead. The field is left
            for backward-compatibility.
        vlan_attachments (MutableSequence[google.cloud.bare_metal_solution_v2.types.VRF.VlanAttachment]):
            The list of VLAN attachments for the VRF.
    """

    class State(proto.Enum):
        r"""The possible states for this VRF.

        Values:
            STATE_UNSPECIFIED (0):
                The unspecified state.
            PROVISIONING (1):
                The vrf is provisioning.
            PROVISIONED (2):
                The vrf is provisioned.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        PROVISIONED = 2

    class QosPolicy(proto.Message):
        r"""QOS policy parameters.

        Attributes:
            bandwidth_gbps (float):
                The bandwidth permitted by the QOS policy, in
                gbps.
        """

        bandwidth_gbps: float = proto.Field(
            proto.DOUBLE,
            number=1,
        )

    class VlanAttachment(proto.Message):
        r"""VLAN attachment details.

        Attributes:
            peer_vlan_id (int):
                The peer vlan ID of the attachment.
            peer_ip (str):
                The peer IP of the attachment.
            router_ip (str):
                The router IP of the attachment.
            pairing_key (str):
                Input only. Pairing key.
            qos_policy (google.cloud.bare_metal_solution_v2.types.VRF.QosPolicy):
                The QOS policy applied to this VLAN
                attachment. This value should be preferred to
                using qos at vrf level.
            id (str):
                Immutable. The identifier of the attachment
                within vrf.
            interconnect_attachment (str):
                Optional. The name of the vlan attachment within vrf. This
                is of the form
                projects/{project_number}/regions/{region}/interconnectAttachments/{interconnect_attachment}
        """

        peer_vlan_id: int = proto.Field(
            proto.INT64,
            number=1,
        )
        peer_ip: str = proto.Field(
            proto.STRING,
            number=2,
        )
        router_ip: str = proto.Field(
            proto.STRING,
            number=3,
        )
        pairing_key: str = proto.Field(
            proto.STRING,
            number=4,
        )
        qos_policy: "VRF.QosPolicy" = proto.Field(
            proto.MESSAGE,
            number=5,
            message="VRF.QosPolicy",
        )
        id: str = proto.Field(
            proto.STRING,
            number=6,
        )
        interconnect_attachment: str = proto.Field(
            proto.STRING,
            number=7,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=5,
        enum=State,
    )
    qos_policy: QosPolicy = proto.Field(
        proto.MESSAGE,
        number=6,
        message=QosPolicy,
    )
    vlan_attachments: MutableSequence[VlanAttachment] = proto.RepeatedField(
        proto.MESSAGE,
        number=7,
        message=VlanAttachment,
    )


class LogicalInterface(proto.Message):
    r"""Each logical interface represents a logical abstraction of
    the underlying physical interface (for eg. bond, nic) of the
    instance. Each logical interface can effectively map to multiple
    network-IP pairs and still be mapped to one underlying physical
    interface.

    Attributes:
        logical_network_interfaces (MutableSequence[google.cloud.bare_metal_solution_v2.types.LogicalInterface.LogicalNetworkInterface]):
            List of logical network interfaces within a
            logical interface.
        name (str):
            Interface name. This is of syntax <bond_mode> or and forms
            part of the network template name.
        interface_index (int):
            The index of the logical interface mapping to
            the index of the hardware bond or nic on the
            chosen network template. This field is
            deprecated.
    """

    class LogicalNetworkInterface(proto.Message):
        r"""Each logical network interface is effectively a network and
        IP pair.

        Attributes:
            network (str):
                Name of the network
            ip_address (str):
                IP address in the network
            default_gateway (bool):
                Whether this interface is the default gateway
                for the instance. Only one interface can be the
                default gateway for the instance.
            network_type (google.cloud.bare_metal_solution_v2.types.Network.Type):
                Type of network.
            id (str):
                An identifier for the ``Network``, generated by the backend.
        """

        network: str = proto.Field(
            proto.STRING,
            number=1,
        )
        ip_address: str = proto.Field(
            proto.STRING,
            number=2,
        )
        default_gateway: bool = proto.Field(
            proto.BOOL,
            number=3,
        )
        network_type: "Network.Type" = proto.Field(
            proto.ENUM,
            number=4,
            enum="Network.Type",
        )
        id: str = proto.Field(
            proto.STRING,
            number=5,
        )

    logical_network_interfaces: MutableSequence[
        LogicalNetworkInterface
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=LogicalNetworkInterface,
    )
    name: str = proto.Field(
        proto.STRING,
        number=2,
    )
    interface_index: int = proto.Field(
        proto.INT32,
        number=3,
    )


class GetNetworkRequest(proto.Message):
    r"""Message for requesting network information.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListNetworksRequest(proto.Message):
    r"""Message for requesting a list of networks.

    Attributes:
        parent (str):
            Required. Parent value for
            ListNetworksRequest.
        page_size (int):
            Requested page size. The server might return
            fewer items than requested. If unspecified,
            server will pick an appropriate default.
        page_token (str):
            A token identifying a page of results from
            the server.
        filter (str):
            List filter.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListNetworksResponse(proto.Message):
    r"""Response message containing the list of networks.

    Attributes:
        networks (MutableSequence[google.cloud.bare_metal_solution_v2.types.Network]):
            The list of networks.
        next_page_token (str):
            A token identifying a page of results from
            the server.
        unreachable (MutableSequence[str]):
            Locations that could not be reached.
    """

    @property
    def raw_page(self):
        return self

    networks: MutableSequence["Network"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Network",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class UpdateNetworkRequest(proto.Message):
    r"""Message requesting to updating a network.

    Attributes:
        network (google.cloud.bare_metal_solution_v2.types.Network):
            Required. The network to update.

            The ``name`` field is used to identify the instance to
            update. Format:
            projects/{project}/locations/{location}/networks/{network}
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update. The only currently supported
            fields are: ``labels``, ``reservations``,
            ``vrf.vlan_attachments``
    """

    network: "Network" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Network",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class NetworkUsage(proto.Message):
    r"""Network with all used IP addresses.

    Attributes:
        network (google.cloud.bare_metal_solution_v2.types.Network):
            Network.
        used_ips (MutableSequence[str]):
            All used IP addresses in this network.
    """

    network: "Network" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Network",
    )
    used_ips: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class ListNetworkUsageRequest(proto.Message):
    r"""Request to get networks with IPs.

    Attributes:
        location (str):
            Required. Parent value (project and
            location).
    """

    location: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListNetworkUsageResponse(proto.Message):
    r"""Response with Networks with IPs

    Attributes:
        networks (MutableSequence[google.cloud.bare_metal_solution_v2.types.NetworkUsage]):
            Networks with IPs.
    """

    networks: MutableSequence["NetworkUsage"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="NetworkUsage",
    )


class NetworkMountPoint(proto.Message):
    r"""Mount point for a network.

    Attributes:
        instance (str):
            Instance to attach network to.
        logical_interface (str):
            Logical interface to detach from.
        default_gateway (bool):
            Network should be a default gateway.
        ip_address (str):
            Ip address of the server.
    """

    instance: str = proto.Field(
        proto.STRING,
        number=1,
    )
    logical_interface: str = proto.Field(
        proto.STRING,
        number=2,
    )
    default_gateway: bool = proto.Field(
        proto.BOOL,
        number=3,
    )
    ip_address: str = proto.Field(
        proto.STRING,
        number=4,
    )


class RenameNetworkRequest(proto.Message):
    r"""Message requesting rename of a server.

    Attributes:
        name (str):
            Required. The ``name`` field is used to identify the
            network. Format:
            projects/{project}/locations/{location}/networks/{network}
        new_network_id (str):
            Required. The new ``id`` of the network.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    new_network_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.bare_metal_solution_v2.types import common
from google.cloud.bare_metal_solution_v2.types import lun as gcb_lun
from google.cloud.bare_metal_solution_v2.types import network, volume

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "Instance",
        "GetInstanceRequest",
        "ListInstancesRequest",
        "ListInstancesResponse",
        "UpdateInstanceRequest",
        "RenameInstanceRequest",
        "ResetInstanceRequest",
        "StartInstanceRequest",
        "StartInstanceResponse",
        "StopInstanceRequest",
        "StopInstanceResponse",
        "EnableInteractiveSerialConsoleRequest",
        "EnableInteractiveSerialConsoleResponse",
        "DisableInteractiveSerialConsoleRequest",
        "DisableInteractiveSerialConsoleResponse",
        "DetachLunRequest",
        "ServerNetworkTemplate",
    },
)


class Instance(proto.Message):
    r"""A server.

    Attributes:
        name (str):
            Immutable. The resource name of this ``Instance``. Resource
            names are schemeless URIs that follow the conventions in
            https://cloud.google.com/apis/design/resource_names. Format:
            ``projects/{project}/locations/{location}/instances/{instance}``
        id (str):
            Output only. An identifier for the ``Instance``, generated
            by the backend.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Create a time stamp.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Update a time stamp.
        machine_type (str):
            Immutable. The server type. `Available server
            types <https://cloud.google.com/bare-metal/docs/bms-planning#server_configurations>`__
        state (google.cloud.bare_metal_solution_v2.types.Instance.State):
            Output only. The state of the server.
        hyperthreading_enabled (bool):
            True if you enable hyperthreading for the
            server, otherwise false. The default value is
            false.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        luns (MutableSequence[google.cloud.bare_metal_solution_v2.types.Lun]):
            Immutable. List of LUNs associated with this
            server.
        volumes (MutableSequence[google.cloud.bare_metal_solution_v2.types.Volume]):
            Input only. List of Volumes to attach to this
            Instance on creation. This field won't be
            populated in Get/List responses.
        networks (MutableSequence[google.cloud.bare_metal_solution_v2.types.Network]):
            Output only. List of networks associated with
            this server.
        interactive_serial_console_enabled (bool):
            Output only. True if the interactive serial
            console feature is enabled for the instance,
            false otherwise. The default value is false.
        os_image (str):
            The OS image currently installed on the
            server.
        pod (str):
            Immutable. Pod name.
            Pod is an independent part of infrastructure.
            Instance can be connected to the assets
            (networks, volumes) allocated in the same pod
            only.
        network_template (str):
            Instance network template name. For eg, bondaa-bondaa,
            bondab-nic, etc. Generally, the template name follows the
            syntax of "bond<bond_mode>" or "nic".
        logical_interfaces (MutableSequence[google.cloud.bare_metal_solution_v2.types.LogicalInterface]):
            List of logical interfaces for the instance. The number of
            logical interfaces will be the same as number of hardware
            bond/nic on the chosen network template. For the
            non-multivlan configurations (for eg, existing servers) that
            use existing default network template (bondaa-bondaa), both
            the Instance.networks field and the
            Instance.logical_interfaces fields will be filled to ensure
            backward compatibility. For the others, only
            Instance.logical_interfaces will be filled.
        login_info (str):
            Output only. Text field about info for
            logging in.
        workload_profile (google.cloud.bare_metal_solution_v2.types.WorkloadProfile):
            The workload profile for the instance.
        firmware_version (str):
            Output only. The firmware version for the
            instance.
    """

    class State(proto.Enum):
        r"""The possible states for this server.

        Values:
            STATE_UNSPECIFIED (0):
                The server is in an unknown state.
            PROVISIONING (1):
                The server is being provisioned.
            RUNNING (2):
                The server is running.
            DELETED (3):
                The server has been deleted.
            UPDATING (4):
                The server is being updated.
            STARTING (5):
                The server is starting.
            STOPPING (6):
                The server is stopping.
            SHUTDOWN (7):
                The server is shutdown.
        """
        STATE_UNSPECIFIED = 0
        PROVISIONING = 1
        RUNNING = 2
        DELETED = 3
        UPDATING = 4
        STARTING = 5
        STOPPING = 6
        SHUTDOWN = 7

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=11,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    machine_type: str = proto.Field(
        proto.STRING,
        number=4,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=5,
        enum=State,
    )
    hyperthreading_enabled: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=7,
    )
    luns: MutableSequence[gcb_lun.Lun] = proto.RepeatedField(
        proto.MESSAGE,
        number=8,
        message=gcb_lun.Lun,
    )
    volumes: MutableSequence[volume.Volume] = proto.RepeatedField(
        proto.MESSAGE,
        number=16,
        message=volume.Volume,
    )
    networks: MutableSequence[network.Network] = proto.RepeatedField(
        proto.MESSAGE,
        number=9,
        message=network.Network,
    )
    interactive_serial_console_enabled: bool = proto.Field(
        proto.BOOL,
        number=10,
    )
    os_image: str = proto.Field(
        proto.STRING,
        number=12,
    )
    pod: str = proto.Field(
        proto.STRING,
        number=13,
    )
    network_template: str = proto.Field(
        proto.STRING,
        number=14,
    )
    logical_interfaces: MutableSequence[network.LogicalInterface] = proto.RepeatedField(
        proto.MESSAGE,
        number=15,
        message=network.LogicalInterface,
    )
    login_info: str = proto.Field(
        proto.STRING,
        number=17,
    )
    workload_profile: common.WorkloadProfile = proto.Field(
        proto.ENUM,
        number=18,
        enum=common.WorkloadProfile,
    )
    firmware_version: str = proto.Field(
        proto.STRING,
        number=19,
    )


class GetInstanceRequest(proto.Message):
    r"""Message for requesting server information.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListInstancesRequest(proto.Message):
    r"""Message for requesting the list of servers.

    Attributes:
        parent (str):
            Required. Parent value for
            ListInstancesRequest.
        page_size (int):
            Requested page size. Server may return fewer
            items than requested. If unspecified, the server
            will pick an appropriate default.
        page_token (str):
            A token identifying a page of results from
            the server.
        filter (str):
            List filter.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListInstancesResponse(proto.Message):
    r"""Response message for the list of servers.

    Attributes:
        instances (MutableSequence[google.cloud.bare_metal_solution_v2.types.Instance]):
            The list of servers.
        next_page_token (str):
            A token identifying a page of results from
            the server.
        unreachable (MutableSequence[str]):
            Locations that could not be reached.
    """

    @property
    def raw_page(self):
        return self

    instances: MutableSequence["Instance"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Instance",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class UpdateInstanceRequest(proto.Message):
    r"""Message requesting to updating a server.

    Attributes:
        instance (google.cloud.bare_metal_solution_v2.types.Instance):
            Required. The server to update.

            The ``name`` field is used to identify the instance to
            update. Format:
            projects/{project}/locations/{location}/instances/{instance}
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update. The currently supported fields
            are: ``labels`` ``hyperthreading_enabled`` ``os_image``
    """

    instance: "Instance" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Instance",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class RenameInstanceRequest(proto.Message):
    r"""Message requesting rename of a server.

    Attributes:
        name (str):
            Required. The ``name`` field is used to identify the
            instance. Format:
            projects/{project}/locations/{location}/instances/{instance}
        new_instance_id (str):
            Required. The new ``id`` of the instance.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    new_instance_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class ResetInstanceRequest(proto.Message):
    r"""Message requesting to reset a server.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class StartInstanceRequest(proto.Message):
    r"""Message requesting to start a server.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class StartInstanceResponse(proto.Message):
    r"""Response message from starting a server."""


class StopInstanceRequest(proto.Message):
    r"""Message requesting to stop a server.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class StopInstanceResponse(proto.Message):
    r"""Response message from stopping a server."""


class EnableInteractiveSerialConsoleRequest(proto.Message):
    r"""Message for enabling the interactive serial console on an
    instance.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class EnableInteractiveSerialConsoleResponse(proto.Message):
    r"""Message for response of EnableInteractiveSerialConsole."""


class DisableInteractiveSerialConsoleRequest(proto.Message):
    r"""Message for disabling the interactive serial console on an
    instance.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class DisableInteractiveSerialConsoleResponse(proto.Message):
    r"""Message for response of DisableInteractiveSerialConsole."""


class DetachLunRequest(proto.Message):
    r"""Message for detach specific LUN from an Instance.

    Attributes:
        instance (str):
            Required. Name of the instance.
        lun (str):
            Required. Name of the Lun to detach.
        skip_reboot (bool):
            If true, performs lun unmapping without
            instance reboot.
    """

    instance: str = proto.Field(
        proto.STRING,
        number=1,
    )
    lun: str = proto.Field(
        proto.STRING,
        number=2,
    )
    skip_reboot: bool = proto.Field(
        proto.BOOL,
        number=3,
    )


class ServerNetworkTemplate(proto.Message):
    r"""Network template.

    Attributes:
        name (str):
            Output only. Template's unique name. The full resource name
            follows the pattern:
            ``projects/{project}/locations/{location}/serverNetworkTemplate/{server_network_template}``
            Generally, the {server_network_template} follows the syntax
            of "bond<interface_type_index><bond_mode>" or
            "nic<interface_type_index>".
        applicable_instance_types (MutableSequence[str]):
            Instance types this template is applicable
            to.
        logical_interfaces (MutableSequence[google.cloud.bare_metal_solution_v2.types.ServerNetworkTemplate.LogicalInterface]):
            Logical interfaces.
    """

    class LogicalInterface(proto.Message):
        r"""Logical interface.

        Attributes:
            name (str):
                Interface name. This is not a globally unique identifier.
                Name is unique only inside the ServerNetworkTemplate. This
                is of syntax <interface_type_index><bond_mode> or
                <interface_type_index> and forms part of the network
                template name.
            type_ (google.cloud.bare_metal_solution_v2.types.ServerNetworkTemplate.LogicalInterface.InterfaceType):
                Interface type.
            required (bool):
                If true, interface must have network
                connected.
        """

        class InterfaceType(proto.Enum):
            r"""Interface type.

            Values:
                INTERFACE_TYPE_UNSPECIFIED (0):
                    Unspecified value.
                BOND (1):
                    Bond interface type.
                NIC (2):
                    NIC interface type.
            """
            INTERFACE_TYPE_UNSPECIFIED = 0
            BOND = 1
            NIC = 2

        name: str = proto.Field(
            proto.STRING,
            number=1,
        )
        type_: "ServerNetworkTemplate.LogicalInterface.InterfaceType" = proto.Field(
            proto.ENUM,
            number=2,
            enum="ServerNetworkTemplate.LogicalInterface.InterfaceType",
        )
        required: bool = proto.Field(
            proto.BOOL,
            number=3,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    applicable_instance_types: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )
    logical_interfaces: MutableSequence[LogicalInterface] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=LogicalInterface,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "OperationMetadata",
        "ResetInstanceResponse",
    },
)


class OperationMetadata(proto.Message):
    r"""Represents the metadata from a long-running operation.

    Attributes:
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation was
            created.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time the operation finished
            running.
        target (str):
            Output only. Server-defined resource path for
            the target of the operation.
        verb (str):
            Output only. Name of the action executed by
            the operation.
        status_message (str):
            Output only. Human-readable status of the
            operation, if any.
        requested_cancellation (bool):
            Output only. Identifies whether the user requested the
            cancellation of the operation. Operations that have been
            successfully cancelled have [Operation.error][] value with a
            [google.rpc.Status.code][google.rpc.Status.code] of 1,
            corresponding to ``Code.CANCELLED``.
        api_version (str):
            Output only. API version used with the
            operation.
    """

    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=1,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=2,
        message=timestamp_pb2.Timestamp,
    )
    target: str = proto.Field(
        proto.STRING,
        number=3,
    )
    verb: str = proto.Field(
        proto.STRING,
        number=4,
    )
    status_message: str = proto.Field(
        proto.STRING,
        number=5,
    )
    requested_cancellation: bool = proto.Field(
        proto.BOOL,
        number=6,
    )
    api_version: str = proto.Field(
        proto.STRING,
        number=7,
    )


class ResetInstanceResponse(proto.Message):
    r"""Response message from resetting a server."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.cloud.bare_metal_solution_v2.types import common

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "Volume",
        "GetVolumeRequest",
        "ListVolumesRequest",
        "ListVolumesResponse",
        "UpdateVolumeRequest",
        "RenameVolumeRequest",
        "EvictVolumeRequest",
        "ResizeVolumeRequest",
    },
)


class Volume(proto.Message):
    r"""A storage volume.

    Attributes:
        name (str):
            Output only. The resource name of this ``Volume``. Resource
            names are schemeless URIs that follow the conventions in
            https://cloud.google.com/apis/design/resource_names. Format:
            ``projects/{project}/locations/{location}/volumes/{volume}``
        id (str):
            An identifier for the ``Volume``, generated by the backend.
        storage_type (google.cloud.bare_metal_solution_v2.types.Volume.StorageType):
            The storage type for this volume.
        state (google.cloud.bare_metal_solution_v2.types.Volume.State):
            The state of this storage volume.
        requested_size_gib (int):
            The requested size of this storage volume, in
            GiB.
        originally_requested_size_gib (int):
            Originally requested size, in GiB.
        current_size_gib (int):
            The current size of this storage volume, in
            GiB, including space reserved for snapshots.
            This size might be different than the requested
            size if the storage volume has been configured
            with auto grow or auto shrink.
        emergency_size_gib (int):
            Additional emergency size that was requested for this
            Volume, in GiB. current_size_gib includes this value.
        max_size_gib (int):
            Maximum size volume can be expanded to in
            case of evergency, in GiB.
        auto_grown_size_gib (int):
            The size, in GiB, that this storage volume
            has expanded as a result of an auto grow policy.
            In the absence of auto-grow, the value is 0.
        remaining_space_gib (int):
            The space remaining in the storage volume for
            new LUNs, in GiB, excluding space reserved for
            snapshots.
        snapshot_reservation_detail (google.cloud.bare_metal_solution_v2.types.Volume.SnapshotReservationDetail):
            Details about snapshot space reservation and
            usage on the storage volume.
        snapshot_auto_delete_behavior (google.cloud.bare_metal_solution_v2.types.Volume.SnapshotAutoDeleteBehavior):
            The behavior to use when snapshot reserved
            space is full.
        labels (MutableMapping[str, str]):
            Labels as key value pairs.
        snapshot_enabled (bool):
            Whether snapshots are enabled.
        pod (str):
            Immutable. Pod name.
        protocol (google.cloud.bare_metal_solution_v2.types.Volume.Protocol):
            Output only. Storage protocol for the Volume.
        boot_volume (bool):
            Output only. Whether this volume is a boot
            volume. A boot volume is one which contains a
            boot LUN.
        performance_tier (google.cloud.bare_metal_solution_v2.types.VolumePerformanceTier):
            Immutable. Performance tier of the Volume.
            Default is SHARED.
        notes (str):
            Input only. User-specified notes for new
            Volume. Used to provision Volumes that require
            manual intervention.
        workload_profile (google.cloud.bare_metal_solution_v2.types.Volume.WorkloadProfile):
            The workload profile for the volume.
        expire_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. Time after which volume will be
            fully deleted. It is filled only for volumes in
            COOLOFF state.
        instances (MutableSequence[str]):
            Output only. Instances this Volume is
            attached to. This field is set only in Get
            requests.
        attached (bool):
            Output only. Is the Volume attached at at least one
            instance. This field is a lightweight counterpart of
            ``instances`` field. It is filled in List responses as well.
    """

    class StorageType(proto.Enum):
        r"""The storage type for a volume.

        Values:
            STORAGE_TYPE_UNSPECIFIED (0):
                The storage type for this volume is unknown.
            SSD (1):
                The storage type for this volume is SSD.
            HDD (2):
                This storage type for this volume is HDD.
        """
        STORAGE_TYPE_UNSPECIFIED = 0
        SSD = 1
        HDD = 2

    class State(proto.Enum):
        r"""The possible states for a storage volume.

        Values:
            STATE_UNSPECIFIED (0):
                The storage volume is in an unknown state.
            CREATING (1):
                The storage volume is being created.
            READY (2):
                The storage volume is ready for use.
            DELETING (3):
                The storage volume has been requested to be
                deleted.
            UPDATING (4):
                The storage volume is being updated.
            COOL_OFF (5):
                The storage volume is in cool off state. It will be deleted
                after ``expire_time``.
        """
        STATE_UNSPECIFIED = 0
        CREATING = 1
        READY = 2
        DELETING = 3
        UPDATING = 4
        COOL_OFF = 5

    class SnapshotAutoDeleteBehavior(proto.Enum):
        r"""The kinds of auto delete behavior to use when snapshot
        reserved space is full.

        Values:
            SNAPSHOT_AUTO_DELETE_BEHAVIOR_UNSPECIFIED (0):
                The unspecified behavior.
            DISABLED (1):
                Don't delete any snapshots. This disables new
                snapshot creation, as long as the snapshot
                reserved space is full.
            OLDEST_FIRST (2):
                Delete the oldest snapshots first.
            NEWEST_FIRST (3):
                Delete the newest snapshots first.
        """
        SNAPSHOT_AUTO_DELETE_BEHAVIOR_UNSPECIFIED = 0
        DISABLED = 1
        OLDEST_FIRST = 2
        NEWEST_FIRST = 3

    class Protocol(proto.Enum):
        r"""Storage protocol.

        Values:
            PROTOCOL_UNSPECIFIED (0):
                Value is not specified.
            FIBRE_CHANNEL (1):
                Fibre Channel protocol.
            NFS (2):
                NFS protocol means Volume is a NFS Share
                volume. Such volumes cannot be manipulated via
                Volumes API.
        """
        PROTOCOL_UNSPECIFIED = 0
        FIBRE_CHANNEL = 1
        NFS = 2

    class WorkloadProfile(proto.Enum):
        r"""The possible values for a workload profile.

        Values:
            WORKLOAD_PROFILE_UNSPECIFIED (0):
                The workload profile is in an unknown state.
            GENERIC (1):
                The workload profile is generic.
            HANA (2):
                The workload profile is hana.
        """
        WORKLOAD_PROFILE_UNSPECIFIED = 0
        GENERIC = 1
        HANA = 2

    class SnapshotReservationDetail(proto.Message):
        r"""Details about snapshot space reservation and usage on the
        storage volume.

        Attributes:
            reserved_space_gib (int):
                The space on this storage volume reserved for
                snapshots, shown in GiB.
            reserved_space_used_percent (int):
                The percent of snapshot space on this storage
                volume actually being used by the snapshot
                copies. This value might be higher than 100% if
                the snapshot copies have overflowed into the
                data portion of the storage volume.
            reserved_space_remaining_gib (int):
                The amount, in GiB, of available space in
                this storage volume's reserved snapshot space.
            reserved_space_percent (int):
                Percent of the total Volume size reserved for snapshot
                copies. Enabling snapshots requires reserving 20% or more of
                the storage volume space for snapshots. Maximum reserved
                space for snapshots is 40%. Setting this field will
                effectively set snapshot_enabled to true.
        """

        reserved_space_gib: int = proto.Field(
            proto.INT64,
            number=1,
        )
        reserved_space_used_percent: int = proto.Field(
            proto.INT32,
            number=2,
        )
        reserved_space_remaining_gib: int = proto.Field(
            proto.INT64,
            number=3,
        )
        reserved_space_percent: int = proto.Field(
            proto.INT32,
            number=4,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    id: str = proto.Field(
        proto.STRING,
        number=11,
    )
    storage_type: StorageType = proto.Field(
        proto.ENUM,
        number=2,
        enum=StorageType,
    )
    state: State = proto.Field(
        proto.ENUM,
        number=3,
        enum=State,
    )
    requested_size_gib: int = proto.Field(
        proto.INT64,
        number=4,
    )
    originally_requested_size_gib: int = proto.Field(
        proto.INT64,
        number=16,
    )
    current_size_gib: int = proto.Field(
        proto.INT64,
        number=5,
    )
    emergency_size_gib: int = proto.Field(
        proto.INT64,
        number=14,
    )
    max_size_gib: int = proto.Field(
        proto.INT64,
        number=17,
    )
    auto_grown_size_gib: int = proto.Field(
        proto.INT64,
        number=6,
    )
    remaining_space_gib: int = proto.Field(
        proto.INT64,
        number=7,
    )
    snapshot_reservation_detail: SnapshotReservationDetail = proto.Field(
        proto.MESSAGE,
        number=8,
        message=SnapshotReservationDetail,
    )
    snapshot_auto_delete_behavior: SnapshotAutoDeleteBehavior = proto.Field(
        proto.ENUM,
        number=9,
        enum=SnapshotAutoDeleteBehavior,
    )
    labels: MutableMapping[str, str] = proto.MapField(
        proto.STRING,
        proto.STRING,
        number=12,
    )
    snapshot_enabled: bool = proto.Field(
        proto.BOOL,
        number=13,
    )
    pod: str = proto.Field(
        proto.STRING,
        number=15,
    )
    protocol: Protocol = proto.Field(
        proto.ENUM,
        number=18,
        enum=Protocol,
    )
    boot_volume: bool = proto.Field(
        proto.BOOL,
        number=19,
    )
    performance_tier: common.VolumePerformanceTier = proto.Field(
        proto.ENUM,
        number=20,
        enum=common.VolumePerformanceTier,
    )
    notes: str = proto.Field(
        proto.STRING,
        number=21,
    )
    workload_profile: WorkloadProfile = proto.Field(
        proto.ENUM,
        number=22,
        enum=WorkloadProfile,
    )
    expire_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=24,
        message=timestamp_pb2.Timestamp,
    )
    instances: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=25,
    )
    attached: bool = proto.Field(
        proto.BOOL,
        number=26,
    )


class GetVolumeRequest(proto.Message):
    r"""Message for requesting storage volume information.

    Attributes:
        name (str):
            Required. Name of the resource.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListVolumesRequest(proto.Message):
    r"""Message for requesting a list of storage volumes.

    Attributes:
        parent (str):
            Required. Parent value for
            ListVolumesRequest.
        page_size (int):
            Requested page size. The server might return
            fewer items than requested. If unspecified,
            server will pick an appropriate default.
        page_token (str):
            A token identifying a page of results from
            the server.
        filter (str):
            List filter.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )


class ListVolumesResponse(proto.Message):
    r"""Response message containing the list of storage volumes.

    Attributes:
        volumes (MutableSequence[google.cloud.bare_metal_solution_v2.types.Volume]):
            The list of storage volumes.
        next_page_token (str):
            A token identifying a page of results from
            the server.
        unreachable (MutableSequence[str]):
            Locations that could not be reached.
    """

    @property
    def raw_page(self):
        return self

    volumes: MutableSequence["Volume"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="Volume",
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    unreachable: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class UpdateVolumeRequest(proto.Message):
    r"""Message for updating a volume.

    Attributes:
        volume (google.cloud.bare_metal_solution_v2.types.Volume):
            Required. The volume to update.

            The ``name`` field is used to identify the volume to update.
            Format:
            projects/{project}/locations/{location}/volumes/{volume}
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            The list of fields to update.
            The only currently supported fields are:

              'labels'
    """

    volume: "Volume" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="Volume",
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class RenameVolumeRequest(proto.Message):
    r"""Message requesting rename of a server.

    Attributes:
        name (str):
            Required. The ``name`` field is used to identify the volume.
            Format:
            projects/{project}/locations/{location}/volumes/{volume}
        new_volume_id (str):
            Required. The new ``id`` of the volume.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    new_volume_id: str = proto.Field(
        proto.STRING,
        number=2,
    )


class EvictVolumeRequest(proto.Message):
    r"""Request for skip volume cooloff and delete it.

    Attributes:
        name (str):
            Required. The name of the Volume.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ResizeVolumeRequest(proto.Message):
    r"""Request for emergency resize Volume.

    Attributes:
        volume (str):
            Required. Volume to resize.
        size_gib (int):
            New Volume size, in GiB.
    """

    volume: str = proto.Field(
        proto.STRING,
        number=1,
    )
    size_gib: int = proto.Field(
        proto.INT64,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.cloud.baremetalsolution.v2",
    manifest={
        "VolumePerformanceTier",
        "WorkloadProfile",
    },
)


class VolumePerformanceTier(proto.Enum):
    r"""Performance tier of the Volume.

    Values:
        VOLUME_PERFORMANCE_TIER_UNSPECIFIED (0):
            Value is not specified.
        VOLUME_PERFORMANCE_TIER_SHARED (1):
            Regular volumes, shared aggregates.
        VOLUME_PERFORMANCE_TIER_ASSIGNED (2):
            Assigned aggregates.
        VOLUME_PERFORMANCE_TIER_HT (3):
            High throughput aggregates.
    """
    VOLUME_PERFORMANCE_TIER_UNSPECIFIED = 0
    VOLUME_PERFORMANCE_TIER_SHARED = 1
    VOLUME_PERFORMANCE_TIER_ASSIGNED = 2
    VOLUME_PERFORMANCE_TIER_HT = 3


class WorkloadProfile(proto.Enum):
    r"""The possible values for a workload profile.

    Values:
        WORKLOAD_PROFILE_UNSPECIFIED (0):
            The workload profile is in an unknown state.
        WORKLOAD_PROFILE_GENERIC (1):
            The workload profile is generic.
        WORKLOAD_PROFILE_HANA (2):
            The workload profile is hana.
    """
    WORKLOAD_PROFILE_UNSPECIFIED = 0
    WORKLOAD_PROFILE_GENERIC = 1
    WORKLOAD_PROFILE_HANA = 2


__all__ = tuple(sorted(__protobuf__.manifest))
